from typing import Union

from aiogram.filters import BaseFilter
from aiogram.types import Message


class ChatTypeFilter(BaseFilter): 
    """
    Фильтр для проверки типа чата.

    Этот фильтр позволяет проверять, соответствует ли тип чата
    заданному значению или списку значений.

    :param chat_type: Тип чата или список типов чатов, которые нужно проверить.
    (private, group, supergroup, etc.)
    """
    def __init__(self, chat_type: Union[str, list]):
        self.chat_type = chat_type

    async def __call__(self, message: Message) -> bool:
        if isinstance(self.chat_type, str):
            return message.chat.type == self.chat_type
        else:
            return message.chat.type in self.chat_type
            