from aiogram import Router, F
from aiogram.types import CallbackQuery
from typing import Type, Optional
from tortoise.models import Model


class ErrorRouter:
    """
    Класс ErrorRouter предназначен для обработки ошибок.

    Параметры:
    - text_model: Optional[Type[Model]]: Модель текста, используемая для получения текста ошибки.
    - slug: Optional[str]: Слаг текста ошибки.
    - text_field: str: Поле текста ошибки.
    - text: str: Текст ошибки.

    Методы:
    - get_router() -> Router: Возвращает настроенный роутер для использования в диспетчере aiogram.
    """
    def __init__(self, 
                 text_model: Optional[Type[Model]] = None, 
                 slug: Optional[str] = None,
                 text_field: str = 'text',
                 text: str = 'Данные устарели, воспользуйтесь командой /start.',
                 ):
        """ 
        :param text_model: Django/TortoiseORM модель текста
        :param slug: Слаг текста
        :param text_field: Поле текста
        :param text: Текст ошибки
        """
        self.text_model = text_model
        self.slug = slug
        self.text_field = text_field
        self.text = text

        self.router = Router()        
        self._setup_handlers()

    def _setup_handlers(self):
        @self.router.callback_query()
        async def handle_error(callback: CallbackQuery):
            if callback.data != 'nothing':
                if self.text_model and self.slug:
                    try:
                        reply_text = await self.text_model.get(slug=self.slug)
                        reply_text = getattr(reply_text, self.text_field)
                    except:
                        reply_text = self.text
                else:
                    reply_text = self.text

                try:
                    await callback.answer(
                        text=reply_text,
                        show_alert=True
                    )
                except:
                    pass
